pub trait Ge<Rhs: ?Sized = Self> {
// Required method
unsafe fn ge(&self, other: &Rhs) -> bool;
}Expand description
Represents C++’s operator>=.
Required Methods
Sourceunsafe fn ge(&self, other: &Rhs) -> bool
unsafe fn ge(&self, other: &Rhs) -> bool
This method tests greater than or equal to (for self and other) and is used by the >=
operator.
Safety
The caller must make sure self and other contain valid pointers. This function
may invoke arbitrary foreign code, so no safety guarantees can be made.