Begin

Trait Begin 

pub trait Begin {
    type Output;

    // Required method
    unsafe fn begin(&self) -> Self::Output;
}
Represents C++’s begin() const function.

Required Associated Types

type Output

Output type.

Required Methods

unsafe fn begin(&self) -> Self::Output

Returns a C++ const iterator object pointing to the beginning of the collection.

Safety

The caller must make sure self contains a valid pointer. This function may invoke arbitrary foreign code, so no safety guarantees can be made.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors