EndMut

Trait EndMut 

pub trait EndMut {
    type Output;

    // Required method
    unsafe fn end_mut(&self) -> Self::Output;
}
Represents C++’s end() function.

Required Associated Types

type Output

Output type.

Required Methods

unsafe fn end_mut(&self) -> Self::Output

Returns a C++ mutable iterator object pointing to the end of the collection.

Safety

The caller must make sure self contains a valid pointer. This function may invoke arbitrary foreign code, so no safety guarantees can be made.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors