Indirection

Trait Indirection 

pub trait Indirection {
    type Output;

    // Required method
    unsafe fn indirection(&self) -> Self::Output;
}
Represents C++’s indirection operator (*a).

Required Associated Types

type Output

Output type.

Required Methods

unsafe fn indirection(&self) -> Self::Output

Returns the object self is pointing to.

Safety

The caller must make sure self contains a valid pointer. This function may invoke arbitrary foreign code, so no safety guarantees can be made.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors