[−][src]Trait cpp_core::cmp::Ge
Represents C++'s operator>=.
Required methods
unsafe fn ge(&self, other: &Rhs) -> bool
This method tests greater than or equal to (for self and other) and is used by the >=
operator.
Safety
The caller must make sure self and other contain valid pointers. This function
may invoke arbitrary foreign code, so no safety guarantees can be made.