pub trait Indirection {
type Output;
// Required method
unsafe fn indirection(&self) -> Self::Output;
}Expand description
Represents C++’s indirection operator (*a).
Required Associated Types
Required Methods
Sourceunsafe fn indirection(&self) -> Self::Output
unsafe fn indirection(&self) -> Self::Output
Returns the object self is pointing to.
Safety
The caller must make sure self contains a valid pointer. This function
may invoke arbitrary foreign code, so no safety guarantees can be made.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".